@@ -17,7 +17,18 @@ xgx_geom_ci <- function(mapping = NULL, data = NULL, conf_level = 0.95,
                         distribution = "normal",
                         geom = list("point", "line", "errorbar"),
                         position = "identity",
-                        ..., fun.args = list(), na.rm = FALSE, show.legend = NA,
-                        inherit.aes = TRUE) {
-  return(list(xgx_stat_ci(conf_level = conf_level, ...)))
+                        fun.args = list(),
+                        na.rm = FALSE,
+                        show.legend = NA,
+                        inherit.aes = TRUE,
+                        ...) {
+  return(list(xgx_stat_ci(mapping, data, conf_level,
+                          distribution,
+                          geom,
+                          position,
+                          fun.args,
+                          na.rm,
+                          show.legend,
+                          inherit.aes,
+                          ...)))
 }
